@@ -1,3 +1,7 @@
+# Primary HydroShare Data Resource
+vaa_hydroshare <-
+  'https://www.hydroshare.org/resource/6092c8a62fac45be97a09bfd0b0bf726/data/contents/nhdplusVAA.fst'
+
 nhdplusTools_env <- new.env()
 
 # NHDPlus Attributes
@@ -22,6 +26,7 @@ Divergence <- "Divergence"
 TerminalPa <- "TerminalPa"
 StartFlag <- "StartFlag"
 FTYPE <- "FTYPE"
+FCODE <- "FCODE"
 FromMeas <- "FromMeas"
 ToMeas <- "ToMeas"
 REACHCODE <- "REACHCODE"
@@ -55,6 +60,7 @@ nhdplus_attributes <- list(
   TerminalPa = TerminalPa,
   StartFlag = StartFlag,
   FTYPE = FTYPE, FType = FTYPE,
+  FCODE = FCODE, FCode = FCODE,
   FromMeas = FromMeas,
   ToMeas = ToMeas,
   REACHCODE = REACHCODE, ReachCode = REACHCODE,
@@ -66,11 +72,11 @@ nhdplus_attributes <- list(
 
 assign("nhdplus_attributes", nhdplus_attributes, envir = nhdplusTools_env)
 
-assign("geoserver_ows_root", "https://labs.waterdata.usgs.gov/geoserver/ows",
+assign("geoserver_root", "https://labs.waterdata.usgs.gov/geoserver/",
        envir = nhdplusTools_env)
 
 assign("prepare_nhdplus_attributes",
-       c("COMID", "LENGTHKM", "FTYPE", "TerminalFl",
+       c("COMID", "LENGTHKM", "TerminalFl",
          "FromNode", "ToNode", "TotDASqKM",
          "StartFlag", "StreamOrde", "StreamCalc",
          "TerminalPa", "Pathlength", "Divergence", "Hydroseq",
@@ -141,8 +147,10 @@ assign("get_waterbody_index_waterbodies_attributes",
        c("COMID"), envir = nhdplusTools_env)
 
 assign("get_waterbody_index_flines_attributes",
-       c("COMID", "WBAREACOMI", "Hydroseq"))
+       c("COMID", "WBAREACOMI", "Hydroseq"), envir = nhdplusTools_env)
 
+# assigned here for record keeping. Used as a status counter in apply functions.
+assign("cur_count", 0, envir = nhdplusTools_env)
 
 check_names <- function(x, function_name) {
   x <- align_nhdplus_names(x)
@@ -257,3 +265,12 @@ align_nhdplus_names <- function(x){
   return(x)
 
 }
+
+
+drop_geometry <- function(x) {
+  if("sf" %in% class(x)) {
+    sf::st_drop_geometry(x)
+  } else {
+    x
+  }
+}
