@@ -37,67 +37,6 @@ test_that("arbolate sum works", {
   expect(max(abs(catchment_length$arb_sum - catchment_length$nhd_arb_sum)) < 1e-2, "arbolate sum not close enough")
 })
 
-test_that("calculate level path", {
-  source(system.file("extdata", "walker_data.R", package = "nhdplusTools"))
-
-  test_flowline <- prepare_nhdplus(walker_flowline, 0, 0, FALSE, warn = FALSE)
-
-  test_flowline <- data.frame(
-    ID = test_flowline$COMID,
-    toID = test_flowline$toCOMID,
-    nameID = walker_flowline$GNIS_ID,
-    weight = walker_flowline$ArbolateSu,
-    stringsAsFactors = FALSE)
-
-  test_flowline <- left_join(test_flowline,
-                             get_levelpaths(test_flowline, status = TRUE), by = "ID")
-
-  nhdp_lp <- sort(unique(walker_flowline$LevelPathI))
-  nhdt_lp <- sort(unique(test_flowline$levelpath))
-
-  expect_true(length(nhdp_lp) == length(nhdt_lp))
-
-  for(lp in seq_along(nhdp_lp)) {
-    nhdp <- filter(walker_flowline, LevelPathI == nhdp_lp[lp])
-    outlet_comid <- filter(nhdp, Hydroseq == min(Hydroseq))$COMID
-    nhdt <- filter(test_flowline, outletID == outlet_comid)
-    expect(all(nhdp$COMID %in% nhdt$ID), paste("Mismatch in", nhdp_lp[lp],
-                                               "level path from NHDPlus."))
-  }
-})
-
-test_that("calculate level path", {
-  source(system.file("extdata", "walker_data.R", package = "nhdplusTools"))
-
-  test_flowline <- prepare_nhdplus(walker_flowline, 0, 0, FALSE, warn = FALSE)
-
-  test_flowline <- data.frame(
-    ID = test_flowline$COMID,
-    toID = test_flowline$toCOMID)
-
-  test_flowline$order <- get_streamorder(test_flowline)
-
-  walker_flowline <- left_join(walker_flowline, test_flowline, by = c("COMID" = "ID"))
-
-  expect_equal(walker_flowline$order, walker_flowline$StreamOrde)
-
-  pt_data <- sf::read_sf(system.file("extdata/petapsco_flowlines.gpkg",
-                                     package = "nhdplusTools"))
-
-  test_flowline <- prepare_nhdplus(pt_data, 0, 0, FALSE, warn = FALSE)
-
-  test_flowline <- data.frame(
-    ID = test_flowline$COMID,
-    toID = test_flowline$toCOMID)
-
-  test_flowline$order <- get_streamorder(test_flowline)
-
-  pt_data <- left_join(filter(pt_data, COMID %in% test_flowline$ID),
-                       test_flowline, by = c("COMID" = "ID"))
-
-  expect_equal(pt_data$order, pt_data$StreamOrde)
-})
-
 test_that("get_pfaf", {
   suppressMessages(
   source(system.file("extdata/nhdplushr_data.R", package = "nhdplusTools")))
@@ -111,7 +50,7 @@ test_that("get_pfaf", {
     st_sf() %>%
     select(ID = COMID, toID = toCOMID, area = AreaSqKM)
 
-  fl$nameID = ""
+  fl$nameID = " "
   fl$totda <- calculate_total_drainage_area(sf::st_set_geometry(fl, NULL))
   fl <- left_join(fl, get_levelpaths(dplyr::rename(sf::st_set_geometry(fl, NULL),
                                                    weight = totda)), by = "ID")
